//	Animal.cpp - The animal class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "Animal.h"
#include "Random.h"

//------------------------------------------------------------------------------
Animal::Animal(const std::wstring& animalType,
			   float islandStart,
			   float islandY):
name(animalType),
bounceIndex(0.0f),
dirScale(-1.0f),
islandPos(islandStart)
{
	moving = Random::getGlobal().getRandomInt(3)-1;
	moveCount = Random::getGlobal().getRandomFloat() * 90.0f;

	position.x = islandStart + (Random::getGlobal().getRandomFloat() * 768.0f);
	position.y = islandY + 64.0f;
	if(name == L"AnimalSlithersheep")
		position.y += 48.0f;
	else if(name == L"AnimalBeavuck")
		position.y += 56.0f;
	else if(name == L"AnimalElemu")
		position.y -= 32.0f;
}

//------------------------------------------------------------------------------
Animal::~Animal()
{

}

//------------------------------------------------------------------------------
void Animal::update()
{
	const float rightBounds = islandPos + 768.0f;

	switch(moving)
	{
		case -1:
			if(position.x > islandPos)
				position.x -= 2.0f;
			if(bounceIndex == 0.0f)
				bounceIndex += 0.1f;
			break;
		case 1:
			if(position.x < rightBounds)
				position.x += 2.0f;
			if(bounceIndex == 0.0f)
				bounceIndex += 0.1f;
			break;
	}

	if(bounceIndex > 0.0f)
	{
		bounceIndex += 0.05f;
		if(bounceIndex > 1.0f)
			bounceIndex = 0.0f;
	}

	moveCount -= 1.0f;
	if(moveCount < 0.0f)
	{
		moveCount = 30.0f + (Random::getGlobal().getRandomFloat() * 90.0f);

		moving = Random::getGlobal().getRandomInt(3)-1;
		if(moving == 1)
			dirScale = -1.0f;
		else if(moving == -1)
			dirScale = 1.0f;
	}
}

//------------------------------------------------------------------------------
void Animal::draw(shared_ptr<Drawer>& d, float xOffset)
{
	float angle;
	TwoFloats tempPos;
	float heightIndex = (position.x - islandPos)/768.0f;
	const TwoFloats imageSize(d->getInternalImageData(name)->size);

	if(((position.x + (imageSize.x*0.5f)) > xOffset) &&
		((position.x - (imageSize.x*0.5f)) < (xOffset + d->getDrawingAreaSize().x)))
	{
		tempPos = position;
		tempPos.x -= xOffset;
		tempPos.x -= imageSize.x*0.5f;
		if(dirScale < 0.0f)
			tempPos.x += imageSize.x;
		tempPos.y -= sinf(bounceIndex * NIALL_PI) * 32.0f;
		tempPos.y -= sinf(heightIndex * NIALL_PI) * 144.0f;
		angle = sinf(bounceIndex * 2.0f * NIALL_PI) * 0.25f;
		d->drawRotImage(name, tempPos, angle, imageSize*0.5f, TwoFloats(dirScale, 1.0f));
	}
}
