//	Animal.h - The animal class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef ANIMAL_H_
#define ANIMAL_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Layer.h"

#include <string>

class Drawer;

///	The animal class.
class Animal : public LayerEntity
{
  public:
	///	Constructor.
	Animal(const std::wstring& animalType, float islandStart, float islandY);
	///	Destructor.
	~Animal();

	///	Moves the player.
	void update();
	///	Draws the player.
	void draw(shared_ptr<Drawer>& d, float xOffset);

	///	Returns the entity's position on the x-axis.
	float getPosition() const {return position.x;};
	///	Returns true if the entity should be considered for collisions.
	bool getCollides() const {return true;};
	///	Returns the entity's type name.
	const std::wstring getType() const {return name;};
  private:
	///	Which animal this is.
	std::wstring name;
	///	The animal's position.
	TwoFloats position;

	///	Used to bounce the animal while he's walking.
	float bounceIndex;
	///	Whether the animal's moving (on land) or not.
	int moving;
	///	Used to determine when to move the animal.
	float moveCount;

	///	Used to draw the animal facing the correct direction.
	float dirScale;

	///	Used to determine how far the player can move on the island.
	float islandPos;
};

#endif
