//	BikiniWhaleEntity.h - The bikini whale.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef BikiniWhaleEntity_H_
#define BikiniWhaleEntity_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Tweener.h"
#include "Layer.h"

class Drawer;

///	The bikini whale.
class BikiniWhaleEntity : public LayerEntity
{
  public:
	///	Constructor.
	BikiniWhaleEntity(float xPos);
	///	Destructor.
	~BikiniWhaleEntity();

	///	Moves the whale.
	void update();
	///	Draws the entity.
	void draw(shared_ptr<Drawer>& d, float xOffset);

	///	Returns the entity's position on the x-axis.
	float getPosition() const {return position.x;};
	///	Returns true if the entity should be considered for collisions.
	bool getCollides() const {return true;};
	///	Returns the entity's type name.
	const std::wstring getType() const {return L"BikiniWhaleEntity";};

	///	Activates the whale.
	void activate();
	///	Returns true if the whale has already been activated.
	bool getActivated() const {return active;};
  private:
	///	The whale's position.
	TwoFloats position;
	///	The whale's rotation.
	float rotation;

	///	The whale's position tweener.
	LogTweener<TwoFloats> posTweener;
	///	The whale's 2nd position tweener.
	ExpTweener<TwoFloats> posTweener2;
	///	Used to fling the whale off the screen if we're headed undersea.
	LogTweener<TwoFloats> posTweener3;
	///	The whale's end position.
	TwoFloats endPosition;

	///	The whale's rotation tweener.
	STweener<float> rotTweener;

	///	True if the whale is active.
	bool active;
};

#endif
