//	ClotheslineMissileEntity.cpp - The clothesline missile.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "ClotheslineMissileEntity.h"
#include "drawing/Drawer.h"
#include "MiscHelper.h"

//------------------------------------------------------------------------------
ClotheslineMissileEntity::ClotheslineMissileEntity(float xPos):
position(xPos, 760.0f),
rotation(0.125f * NIALL_PI),
posTweener(position, position, 0.005f),
posTweener2(position, position, 0.01f),
rotTweener(rotation, (-0.125f * NIALL_PI), 0.005f),
active(false)
{
	endPosition = position;
	endPosition.x -= 1280.0f;
	posTweener.reset(TwoFloats(position.x-1792.0f, -1280.0f));
	posTweener2.setIndex(1.0f);
}

//------------------------------------------------------------------------------
ClotheslineMissileEntity::~ClotheslineMissileEntity()
{

}

//------------------------------------------------------------------------------
void ClotheslineMissileEntity::update()
{
	if(active)
	{
		if(!posTweener.getFinished())
		{
			posTweener.tick();
			if(posTweener.getFinished())
			{
				posTweener2.reset(endPosition);
			}
		}
		/*if(!posTweener2.getFinished())
			posTweener2.tick();*/

		if(!rotTweener.getFinished())
		{
			rotTweener.tick();
			/*if(rotTweener.getFinished() && (rotation > (-NIALL_PI * 0.125f)))
				rotTweener.reset(-NIALL_PI * 0.125f);*/
		}
	}
}

//------------------------------------------------------------------------------
void ClotheslineMissileEntity::draw(shared_ptr<Drawer>& d, float xOffset)
{
	TwoFloats tempPos(position);

	tempPos.x -= xOffset;
	tempPos.x -= 149.0f;
	d->drawRotImage(L"ClotheslineMissile", tempPos, rotation, TwoFloats(512.0f, 150.0f));
}

//------------------------------------------------------------------------------
void ClotheslineMissileEntity::activate()
{
	active = true;
}
