//	IslandEntity.h - Class representing an island.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef ISLANDENTITY_H_
#define ISLANDENTITY_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Layer.h"

class Drawer;

///	Class representing an island.
class IslandEntity : public LayerEntity
{
  public:
	///	Constructor.
	IslandEntity(const TwoFloats& pos);
	///	Destructor.
	~IslandEntity();

	///	Draws the island.
	void draw(shared_ptr<Drawer>& d, float xOffset);

	///	Returns the entity's position on the x-axis.
	float getPosition() const {return position.x;};
	///	Returns true if the entity should be considered for collisions.
	bool getCollides() const {return true;};
	///	Returns the entity's type name.
	const std::wstring getType() const {return L"Island";};
  private:
	///	The island's position.
	TwoFloats position;
};

#endif
