//	JournalDisplay.cpp - The journal class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "JournalDisplay.h"

//------------------------------------------------------------------------------
JournalDisplay::JournalDisplay():
currentPage(0)
{
	Page initialPage;

	initialPage.title = L"How to Play";
	initialPage.image = L"HowToPlay";
	initialPage.text = L"Charles -\n\
\n\
My dear boy. As ever, your interpretation is entirely too literal. I go to \
seek the truth.\n\
\n\
I expect I shall return some time in the new year.";
	pages.push_back(initialPage);
}

//------------------------------------------------------------------------------
JournalDisplay::~JournalDisplay()
{

}

//------------------------------------------------------------------------------
void JournalDisplay::draw(shared_ptr<Drawer>& d)
{
	const TwoFloats centre(d->getDrawingAreaSize() * 0.5f);
	TwoFloats topLeft;

	topLeft = TwoFloats(centre.x-406.0f, centre.y-360.0f);
	d->drawImage(L"Journal", topLeft);

	topLeft.x += 86.0f;
	topLeft.y += 70.0f + 32.0f;
	d->drawText(pages[currentPage].title,
				L"JournalFont0",
				titleLayout,
				topLeft,
				300.0f,
				TextLayout::Centre);
	if(pages[currentPage].image == L"HowToPlay")
	{
		topLeft = TwoFloats(centre.x-406.0f, centre.y-360.0f);
		d->drawImage(pages[currentPage].image, topLeft);
	}
	else if(pages[currentPage].image != L"")
	{
		topLeft.x = centre.x-406.0f+224.0f;
		topLeft.x -= (d->getInternalImageData(pages[currentPage].image)->size.x * 0.5f);
		topLeft.y += 150.0f;
		d->drawImage(pages[currentPage].image, topLeft);
	}

	topLeft.x = centre.x + 30.0f;
	topLeft.y = centre.y-360.0f + 70.0f + 32.0f;
	d->drawText(pages[currentPage].text,
				L"JournalFont0",
				textLayout,
				topLeft,
				332.0f);

	if(currentPage > 0)
	{
		d->drawImage(L"JournalArrow",
					 TwoFloats(centre.x-406.0f+60.0f+(64.0f*0.66f),
							   centre.y+250.0f),
					 TwoFloats(-0.66f, 0.66f));
	}
	if(currentPage < (pages.size()-1))
	{
		d->drawImage(L"JournalArrow",
					 TwoFloats(centre.x+406.0f-110.0f,
							   centre.y+250.0f),
					 0.66f);
	}
}

//------------------------------------------------------------------------------
void JournalDisplay::changePage(int val)
{
	currentPage += val;
	if(currentPage >= (int)pages.size())
		currentPage = pages.size()-1;
	else if(currentPage < 0)
		currentPage = 0;

	titleLayout.clear();
	textLayout.clear();
}

//------------------------------------------------------------------------------
void JournalDisplay::addPage(const std::wstring title,
							 const std::wstring image,
							 const std::wstring text)
{
	Page tempPage;

	tempPage.title = title;
	tempPage.image = image;
	tempPage.text = text;

	pages.push_back(tempPage);

	currentPage = pages.size()-1;
	titleLayout.clear();
	textLayout.clear();
}
