//	JournalDisplay.h - The journal class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef JOURNAL_H_
#define JOURNAL_H_

#include "drawing/TextLayout.h"
#include "c0xHeaders.h"

#include <vector>
#include <string>

class Drawer;

///	The journal class.
class JournalDisplay
{
  public:
	///	Constructor.
	JournalDisplay();
	///	Destructor.
	~JournalDisplay();

	///	Draws the journal.
	void draw(shared_ptr<Drawer>& d);

	///	Changes page.
	/*!
		\param val How much to increment/decrement the current page.
	 */
	void changePage(int val);

	///	Adds a page to the journal.
	void addPage(const std::wstring title,
				 const std::wstring image,
				 const std::wstring text);
  private:
	///	Represents a single page.
	struct Page
	{
		///	Title (on left page).
		std::wstring title;
		///	Image (on left page).
		std::wstring image;
		///	Text (on right page).
		std::wstring text;
	};

	///	The journal's pages.
	std::vector<Page> pages;
	///	The currently displayed page.
	int currentPage;

	///	The current title TextLayout.
	TextLayout titleLayout;
	///	The current text TextLayout.
	TextLayout textLayout;
};

#endif
