//	Layer.h - The classes used to handle the different visual layers.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef LAYER_H_
#define LAYER_H_

#include "c0xHeaders.h"

#include <vector>
#include <string>

class Drawer;

//------------------------------------------------------------------------------
///	Represents an entity that exists within a particular layer.
class LayerEntity
{
  public:
	///	Constructor.
	LayerEntity() {};
	///	Destructor.
	virtual ~LayerEntity() {};

	///	Draws the entity.
	virtual void draw(shared_ptr<Drawer>& d, float xOffset) = 0;

	///	Returns the entity's position on the x-axis.
	virtual float getPosition() const = 0;
	///	Returns true if the entity should be considered for collisions.
	virtual bool getCollides() const = 0;
	///	Returns the entity's type name.
	virtual const std::wstring getType() const = 0;
};

//------------------------------------------------------------------------------
///	Represents a single layer.
class Layer
{
  public:
	///	Constructor.
	Layer();
	///	Destructor.
	~Layer();

	///	Draws the layer.
	void draw(shared_ptr<Drawer>& d, float xOffset);

	///	Adds an entity to the layer.
	void addEntity(shared_ptr<LayerEntity> entity);
	///	Removes an entity from the layer.
	void removeEntity(shared_ptr<LayerEntity> entity);

	///	Returns the number of entities in this layer.
	int getNumEntities() const {return entities.size();};
	///	Returns the indexed entity in this layer.
	shared_ptr<LayerEntity>& getEntity(int index) {return entities[index];};
  private:
	///	This layer's entities.
	std::vector<shared_ptr<LayerEntity> > entities;
};

#endif
