//	OctopusArm.cpp - The Octopus arm.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "OctopusArm.h"
#include "Random.h"

//------------------------------------------------------------------------------
OctopusArm::OctopusArm(const TwoFloats& pos, float scale):
position(pos),
size(scale, 1.0f),
punchTween(position, position, 0.066f),
returnPos(position)
{
	circleIndex = Random::getGlobal().getRandomFloat();

	punchTween.setIndex(1.0f);
}

//------------------------------------------------------------------------------
OctopusArm::~OctopusArm()
{

}

//------------------------------------------------------------------------------
void OctopusArm::update()
{
	if(!punchTween.getFinished())
	{
		punchTween.tick();
		if(punchTween.getFinished())
		{
			if(position != returnPos)
				punchTween.reset(returnPos);
		}
	}
	else
	{
		circleIndex += 0.005f;
		if(circleIndex > 1.0f)
			circleIndex = 0.0f;
	}
}

//------------------------------------------------------------------------------
void OctopusArm::draw(shared_ptr<Drawer>& d, float xOffset)
{
	TwoFloats tempPos(position);

	if(((position.x+220.0f) > xOffset) &&
	   (position.x < (xOffset+d->getDrawingAreaSize().x)))
	{
		tempPos.x -= xOffset;
		if(size.x < 0.0f)
			tempPos.x += 220.0f;

		tempPos.x += sinf(circleIndex * 2.0f * NIALL_PI) * 16.0f;
		tempPos.y += cosf(circleIndex * 2.0f * NIALL_PI) * 8.0f;

		d->drawImage(L"OctopusArm", tempPos, size);
	}
}

//------------------------------------------------------------------------------
void OctopusArm::punch()
{
	if(size.x > 0.0f)
	{
		if(punchTween.getFinished())
			punchTween.reset(TwoFloats(position.x-256.0f, position.y));
	}
}
