//	OctopusArm.h - The Octopus arm.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef OCTOPUSARM_H_
#define OCTOPUSARM_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Tweener.h"
#include "Layer.h"

class Drawer;

///	The Octopus arm.
class OctopusArm : public LayerEntity
{
  public:
	///	Constructor.
	OctopusArm(const TwoFloats& pos, float scale);
	///	Destructor.
	~OctopusArm();

	///	Moves the arm.
	void update();
	///	Draws the entity.
	void draw(shared_ptr<Drawer>& d, float xOffset);

	///	Returns the entity's position on the x-axis.
	float getPosition() const {return position.x;};
	///	Returns true if the entity should be considered for collisions.
	bool getCollides() const {return true;};
	///	Returns the entity's type name.
	const std::wstring getType() const {return L"OctopusArm";};

	///	Tells the arm to punch the player.
	void punch();
	///	Returns true if the arm is currently punching the player.
	bool isPunching() const {return punchTween.getFinished();};
  private:
	///	The arm's position.
	TwoFloats position;
	///	How to scale the arm's image.
	TwoFloats size;

	///	Used to circle the arm.
	float circleIndex;

	///	Used to punch the player.
	ExpTweener<TwoFloats> punchTween;
	///	Used to punch the player.
	TwoFloats returnPos;
};

#endif
