//	Periscope.cpp - The submarine periscope.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "Periscope.h"

//------------------------------------------------------------------------------
Periscope::Periscope(float pos):
position(pos, 640.0f),
raise(true),
active(false),
xScale(1.0f),
flipCount(60.0f),
finished(false)
{

}

//------------------------------------------------------------------------------
Periscope::~Periscope()
{

}

//------------------------------------------------------------------------------
void Periscope::update()
{
	if(active)
	{
		if(raise)
		{
			if(position.y > 440.0f)
			{
				position.y -= 1.0f;
				if(position.y < 440.0f)
					position.y = 440.0f;
			}
			else
			{
				flipCount -= 1.0f;
				if(flipCount <= 0.0f)
				{
					xScale *= -1.0f;
					if(xScale > 0.0f)
						raise = false;

					flipCount = 60.0f;
				}
			}
		}
		else if(position.y < 640.0f)
		{
			position.y += 1.0f;
			if(position.y > 640.0f)
				position.y = 640.0f;

			if(position.y > 480.0f)
				finished = true;
		}
	}
}

//------------------------------------------------------------------------------
void Periscope::draw(shared_ptr<Drawer>& d, float xOffset)
{
	TwoFloats tempPos(position);

	if(((position.x+151.0f) > xOffset) &&
	   (position.x < (xOffset+d->getDrawingAreaSize().x)))
	{
		tempPos.x -= xOffset;
		if(xScale < 0.0f)
			tempPos.x += 151.0f + 64.0f;

		d->drawImage(L"Periscope", tempPos, TwoFloats(xScale, 1.0f));
	}
}

//------------------------------------------------------------------------------
void Periscope::activate()
{
	active = true;
}
