//	Periscope.h - The submarine periscope.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PERISCOPE_H_
#define PERISCOPE_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Layer.h"

class Drawer;

///	The submarine periscope.
class Periscope : public LayerEntity
{
  public:
	///	Constructor.
	Periscope(float pos);
	///	Destructor.
	~Periscope();

	///	Updates the entity.
	void update();
	///	Draws the entity.
	void draw(shared_ptr<Drawer>& d, float xOffset);

	///	Returns true if the periscope has finished its observation.
	bool getFinished() const {return finished;};

	///	Returns the entity's position on the x-axis.
	float getPosition() const {return position.x;};
	///	Returns true if the entity should be considered for collisions.
	bool getCollides() const {return true;};
	///	Returns the entity's type name.
	const std::wstring getType() const {return L"Periscope";};

	///	Activates the periscope.
	void activate();
	///	Returns whether or not the periscope is active.
	bool getActive() const {return active;};
  private:
	///	The periscope's position.
	TwoFloats position;
	///	Used to raise/lower the periscope.
	bool raise;
	///	True if the periscope is active.
	bool active;

	///	Used to flip the periscope horizontally.
	float xScale;
	///	Used to flip the periscope horizontally.
	float flipCount;

	///	True if the periscope has finished its observation.
	bool finished;
};

#endif
