//	Player.cpp - The Arwin character.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "Player.h"

//------------------------------------------------------------------------------
Player::Player():
position(640.0f-48.0f, (314.0f + (3.0f * ((720.0f-314.0f)/8.0f)))-72.0f),
layer(3),
bounceIndex(0.0f),
moving(false),
dirScale(1.0f),
islandPos(0.0f),
onIsland(false),
writing(false),
nausea(0.25f),
hunger(0.25f),
lives(3),
laudanumTimer(0.0f)
{

}

//------------------------------------------------------------------------------
Player::~Player()
{

}

//------------------------------------------------------------------------------
void Player::update()
{
	const float rightBounds = islandPos + 768.0f;

	switch(moving)
	{
		case -1:
			position.x -= 2.0f;
			if(bounceIndex == 0.0f)
				bounceIndex += 0.1f;
			break;
		case 1:
			if(position.x < rightBounds)
				position.x += 2.0f;
			if(bounceIndex == 0.0f)
				bounceIndex += 0.1f;
			break;
	}

	if(bounceIndex > 0.0f)
	{
		bounceIndex += 0.05f;
		if(bounceIndex > 1.0f)
			bounceIndex = 0.0f;
	}

	/*if(hunger < 1.0f)
		hunger += 0.00029f * delta;
	if(nausea > 0.0f)
		nausea -= 0.0002f * delta;
	if(laudanumTimer > 0.0f)
		laudanumTimer -= 0.003f * delta;*/
}

//------------------------------------------------------------------------------
void Player::draw(shared_ptr<Drawer>& d, float xOffset)
{
	float angle;
	TwoFloats tempPos;
	float alpha = 1.0f;
	std::wstring image = L"EstherStanding";
	float heightIndex = (position.x - islandPos)/768.0f;

	if(lives <= 0)
		alpha = 0.5f;

	tempPos = position;
	tempPos.x -= xOffset;
	tempPos.x -= 41.0f;
	if(dirScale < 0.0f)
		tempPos.x += 82.0f;
	tempPos.y -= sinf(bounceIndex * NIALL_PI) * 32.0f;
	tempPos.y -= sinf(heightIndex * NIALL_PI) * 144.0f;
	if(onIsland)
		tempPos.y -= 44.0f;
	angle = sinf(bounceIndex * 2.0f * NIALL_PI) * 0.25f;

	if(writing)
	{
		tempPos.x -= 10.0f;
		tempPos.y += 64.0f;
		image = L"EstherCrosslegged";
	}
	d->drawRotImage(image,
					tempPos,
					angle,
					TwoFloats(40.5f, 96.0f),
					TwoFloats(dirScale, 1.0f),
					1.0f,
					alpha);
}

//------------------------------------------------------------------------------
void Player::setPosition(float pos)
{
	position.x = pos;
	islandPos = pos;
	bounceIndex = 0.0f;
	moving = 0;
	dirScale = 1.0f;
}

//------------------------------------------------------------------------------
void Player::setPosition(const TwoFloats& pos)
{
	position = pos;
}

//------------------------------------------------------------------------------
void Player::setLayer(int val, float screenHeight)
{
	layer = val;
	position.y = 314.0f + ((float)val * ((screenHeight-314.0f)/8.0f));
	position.y -= 72.0f;
}

//------------------------------------------------------------------------------
void Player::move(int val)
{
	moving = val;
	if(moving == -1)
		dirScale = -1.0f;
	else if(moving == 1)
		dirScale = 1.0f;
}

//------------------------------------------------------------------------------
void Player::setIslandPos(float pos)
{
	islandPos = pos;
}

//------------------------------------------------------------------------------
void Player::setOnIsland(bool val)
{
	onIsland = val;
}

//------------------------------------------------------------------------------
void Player::setWriting(bool val)
{
	writing = val;
}

//------------------------------------------------------------------------------
void Player::increaseNausea(float val)
{
	nausea += val;
	if(nausea > 1.0f)
		nausea = 1.0f;
}

//------------------------------------------------------------------------------
void Player::decreaseNausea(float val)
{
	nausea -= val;
	if(nausea < 0.0f)
		nausea = 0.0f;
	laudanumTimer = 1.0f;
}

//------------------------------------------------------------------------------
void Player::decreaseHunger(float val)
{
	hunger -= val;
	if(hunger < 0.0f)
		hunger = 0.0f;
}

//------------------------------------------------------------------------------
void Player::decrementLife()
{
	if(lives > 0)
	{
		--lives;
		if(hunger > 0.5f)
			hunger -= 0.5f;
		else
			hunger = 0.0f;
	}
}
