//	PlayerShip.cpp - The player's ship.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "PlayerShip.h"

//------------------------------------------------------------------------------
PlayerShip::PlayerShip():
position(640.0f, (314.0f + (3.0f * ((720.0f-314.0f)/8.0f)))-64.0f),
speed(0.0f),
layer(3),
moving(0),
punchTween(position, position, 0.065f),
dropTween(position, position, 0.01f),
octoTween(position, position, 0.065f),
intoMouth(false)
{
	punchTween.setDelay(1.0f);
	punchTween.setIndex(1.0f);
	dropTween.setIndex(1.0f);
	octoTween.setIndex(1.0f);
	octoTween.setDelay(0.0f);
}

//------------------------------------------------------------------------------
PlayerShip::~PlayerShip()
{

}

//------------------------------------------------------------------------------
void PlayerShip::update()
{
	if(intoMouth)
	{
		position.x += 1.5f;
		return;
	}
	if(sinking)
	{
		if(position.y < 600.0f)
			position.y += 1.5f;

		return;
	}

	switch(moving)
	{
		case -1:
			if(position.x > 0.0f)
			{
				speed -= 0.01f;
				if(speed < -1.5f)
					speed = -1.5f;
				position.x += speed;
			}
			else
			{
				position.x = 0.0f;
				speed = 0.0f;
			}
			break;
		case 0:
			if(speed > 0.0f)
			{
				speed -= 0.02f;
				if(speed < 0.0f)
					speed = 0.0f;
			}
			else if(speed < 0.0f)
			{
				speed += 0.02f;
				if(speed > 0.0f)
					speed = 0.0f;
			}
			position.x += speed;
			break;
		case 1:
			if(position.x < (14336.0f-256.0f))
			{
				speed += 0.01f;
				if(speed > 1.5f)
					speed = 1.5f;
				/*if(speed > 8.0f)
					speed = 8.0f;*/
				position.x += speed;
			}
			else
			{
				position.x = (14336.0f-256.0f);
				speed = 0.0f;
			}
			break;
	}

	if(!punchTween.getFinished())
	{
		punchTween.tick();
		if(punchTween.getFinished())
		{
			dropTween.reset(punchDestination);
			punchDestination = 0.0f;
		}
	}
	else if(punchDestination != 0.0f)
	{
		dropTween.reset(punchDestination);
		punchDestination = 0.0f;
	}

	if(!dropTween.getFinished())
		dropTween.tick();

	if(!octoTween.getFinished())
		octoTween.tick(1.0f);
}

//------------------------------------------------------------------------------
void PlayerShip::draw(shared_ptr<Drawer>& d, float xOffset)
{
	TwoFloats tempPos;

	tempPos = position;
	tempPos.x -= xOffset;
	tempPos.x -= 128.0f;
	d->drawImage(L"Ship", tempPos);
}

//------------------------------------------------------------------------------
void PlayerShip::setLayer(int val, float screenHeight)
{
	layer = val;
	position.y = 314.0f + ((float)val * ((screenHeight-314.0f)/8.0f));
	position.y -= 64.0f;
}

//------------------------------------------------------------------------------
void PlayerShip::setPosition(float pos)
{
	position.x = pos;
}

//------------------------------------------------------------------------------
void PlayerShip::move(int val)
{
	moving = val;
}

//------------------------------------------------------------------------------
void PlayerShip::punch()
{
	punchDestination = TwoFloats(position.x + 384.0f, position.y);
	punchTween.reset(TwoFloats(position.x, 0.0f));
}

//------------------------------------------------------------------------------
void PlayerShip::sink()
{
	sinking = true;
}

//------------------------------------------------------------------------------
void PlayerShip::octopusPunch()
{
	if(octoTween.getFinished())
		octoTween.reset(TwoFloats(position.x-256.0f, position.y));
}

//------------------------------------------------------------------------------
void PlayerShip::goIntoMouth()
{
	intoMouth = true;
}
