//	PlayerShip.h - The player's ship.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYERSHIP_H_
#define PLAYERSHIP_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Tweener.h"
#include "Layer.h"

class Drawer;

///	The player's ship.
class PlayerShip : public LayerEntity
{
  public:
	///	Constructor.
	PlayerShip();
	///	Destructor.
	~PlayerShip();

	///	Moves the ship.
	void update();
	///	Draws the ship.
	void draw(shared_ptr<Drawer>& d, float xOffset);

	///	Returns the entity's position on the x-axis.
	float getPosition() const {return position.x;};
	///	Returns true if the entity should be considered for collisions.
	bool getCollides() const {return true;};
	///	Returns the entity's type name.
	const std::wstring getType() const {return L"PlayerShip";};

	///	Moves the ship to the set layer.
	void setLayer(int val, float screenHeight);
	///	Returns the ship's current layer.
	int getLayer() const {return layer;};
	///	Used to move the ship back when the player leaves an island.
	void setPosition(float pos);

	///	Tells the ship to move (-1 = left, 0 = stop, 1 = right).
	void move(int val);

	///	Called when the ship is punched.
	void punch();
	///	Returns true if the ship is reacting to being punched.
	bool isPunched() const {return (!punchTween.getFinished() || !dropTween.getFinished());};
	///	Returns the ship's y-axis position.
	float getYPos() const {return position.y;};

	///	Called when the ship is sunk by the Bikini Whale.
	void sink();
	///	Returns true if the ship is sinking.
	bool getSinking() const {return sinking;};

	///	Called when the ship is punched by the octopus.
	void octopusPunch();
	///	Returns true if the ship is reacting to being by the octopus.
	bool isOctoPunched() const {return !octoTween.getFinished();};

	///	Instructs the ship to sail into poseidon's mouth.
	void goIntoMouth();
  private:
	///	The ship's position.
	TwoFloats position;
	///	The ship's speed.
	float speed;
	///	The ship's current layer.
	int layer;

	///	Whether the ship's moving or not.
	int moving;

	///	Used to fling the ship when it's punched.
	ExpTweener<TwoFloats> punchTween;
	///	Used to drop the ship after it's been punched.
	LogTweener<TwoFloats> dropTween;
	///	This value will be non-zero just after the player's been punched.
	TwoFloats punchDestination;

	///	Used to move the ship when the octopus punches it.
	Tweener<TwoFloats> octoTween;

	///	True if the ship is now sailing into poseidon's mouth.
	bool intoMouth;
	///	True if the ship is sinking.
	bool sinking;
};

#endif
