//	PoseidonsPunchingHand.cpp - Poseidon's punching hand.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "PoseidonsPunchingHand.h"
#include "drawing/Drawer.h"
#include "MiscHelper.h"

//------------------------------------------------------------------------------
PoseidonsPunchingHand::PoseidonsPunchingHand(float xPos):
position(xPos, 768.0f),
yTween(position.y, position.y, 0.05f),
active(false)
{
	yTween.setIndex(1.0f);
}

//------------------------------------------------------------------------------
PoseidonsPunchingHand::~PoseidonsPunchingHand()
{

}

//------------------------------------------------------------------------------
void PoseidonsPunchingHand::update()
{
	if(active)
	{
		if(!yTween.getFinished())
			yTween.tick();
		else if(position.y <= 128.0f)
			yTween.reset(768.0f);
		else
			yTween.reset(128.0f);
	}
}

//------------------------------------------------------------------------------
void PoseidonsPunchingHand::draw(shared_ptr<Drawer>& d, float xOffset)
{
	TwoFloats tempPos(position);

	tempPos.x -= xOffset;
	tempPos.x -= 149.0f;
	d->drawImage(L"PoseidonHand", tempPos);
}

//------------------------------------------------------------------------------
void PoseidonsPunchingHand::activate()
{
	active = true;
	yTween.reset(256.0f);
}
