//	PoseidonsPunchingHand.h - Poseidon's punching hand.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef POSEIDONSPUNCHINGHAND_H_
#define POSEIDONSPUNCHINGHAND_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Tweener.h"
#include "Layer.h"

class Drawer;

///	Poseidon's punching hand.
class PoseidonsPunchingHand : public LayerEntity
{
  public:
	///	Constructor.
	PoseidonsPunchingHand(float xPos);
	///	Destructor.
	~PoseidonsPunchingHand();

	///	Moves the hand.
	void update();
	///	Draws the entity.
	void draw(shared_ptr<Drawer>& d, float xOffset);

	///	Returns the entity's position on the x-axis.
	float getPosition() const {return position.x;};
	///	Returns true if the entity should be considered for collisions.
	bool getCollides() const {return true;};
	///	Returns the entity's type name.
	const std::wstring getType() const {return L"PoseidonsPunchingHand";};

	///	Activates the hand.
	void activate();
	///	Returns true if the hand is already activated.
	bool getActivated() const {return active;};
  private:
	///	The hand's position.
	TwoFloats position;

	///	Used to move the hand vertically.
	ExpTweener<float> yTween;

	///	True if the hand is active.
	bool active;
};

#endif
