//	TitleScreen.cpp - The title screen state.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "sound/GenericFileSounder.h"
#include "drawing/Drawer.h"
#include "TitleScreen.h"
#include "MiscHelper.h"
#include "Random.h"
#include "Wave.h"

using std::wstring;
using std::vector;

//------------------------------------------------------------------------------
GameStateCreator<TitleScreen> TitleScreen::creator;
float TitleScreen::fadeIn = 1.0f;

//------------------------------------------------------------------------------
TitleScreen::TitleScreen(Application& app, SounderPtr& sound):
GameState(app, sound),
moonPos(1180.0f, 32.0f),
backgroundOffset(0.0f),
sounder(dynamic_pointer_cast<GenericFileSounder>(sound))
{
	int i;
	float y;

	if(!sounder->getMusicIsPlaying())
		sounder->playMusic(L"Music");

	stars.push_back(TwoFloats(10.0f));
	stars.push_back(TwoFloats(32.0f, 128.0f));
	stars.push_back(TwoFloats(128.0f, 64.0f));
	stars.push_back(TwoFloats(160.0f, 256.0f));
	stars.push_back(TwoFloats(192.0f, 32.0f));
	stars.push_back(TwoFloats(208.0f, 160.0f));
	stars.push_back(TwoFloats(256.0f, 16.0f));
	stars.push_back(TwoFloats(384.0f, 192.0f));
	stars.push_back(TwoFloats(320.0f, 320.0f));

	stars.push_back(TwoFloats(384.0f+32.0f, 128.0f));
	stars.push_back(TwoFloats(384.0f+10.0f, 32.0f));
	stars.push_back(TwoFloats(384.0f+160.0f, 192.0f));
	stars.push_back(TwoFloats(384.0f+128.0f, 64.0f));
	stars.push_back(TwoFloats(384.0f+384.0f, 256.0f));
	stars.push_back(TwoFloats(384.0f+256.0f, 16.0f));
	stars.push_back(TwoFloats(384.0f+320.0f, 320.0f));
	stars.push_back(TwoFloats(384.0f+208.0f, 160.0f));
	stars.push_back(TwoFloats(384.0f+192.0f, 128.0f));

	stars.push_back(TwoFloats(768.0f+128.0f, 128.0f));
	stars.push_back(TwoFloats(768.0f+10.0f, 32.0f));
	stars.push_back(TwoFloats(768.0f+160.0f, 64.0f));
	stars.push_back(TwoFloats(768.0f+32.0f, 192.0f));
	stars.push_back(TwoFloats(768.0f+320.0f, 256.0f));
	stars.push_back(TwoFloats(768.0f+208.0f, 320.0f));
	stars.push_back(TwoFloats(768.0f+192.0f, 16.0f));
	stars.push_back(TwoFloats(768.0f+256.0f, 160.0f));
	stars.push_back(TwoFloats(768.0f+384.0f, 128.0f));

	stars.push_back(TwoFloats(1152.0f+128.0f, 16.0f));
	stars.push_back(TwoFloats(1152.0f+32.0f, 320.0f));
	stars.push_back(TwoFloats(1152.0f+160.0f, 64.0f));
	stars.push_back(TwoFloats(1152.0f+64.0f, 192.0f));
	stars.push_back(TwoFloats(1152.0f+320.0f, 32.0f));
	stars.push_back(TwoFloats(1152.0f+128.0f, 320.0f));
	stars.push_back(TwoFloats(1152.0f+192.0f, 16.0f));
	stars.push_back(TwoFloats(1152.0f+256.0f, 160.0f));
	stars.push_back(TwoFloats(1152.0f+160.0f, 256.0f));

	stars.push_back(TwoFloats(1536.0f+64.0f, 192.0f));
	stars.push_back(TwoFloats(1536.0f+256.0f, 160.0f));
	stars.push_back(TwoFloats(1536.0f+96.0f, 32.0f));
	stars.push_back(TwoFloats(1536.0f+384.0f, 16.0f));
	stars.push_back(TwoFloats(1536.0f+16.0f, 64.0f));
	stars.push_back(TwoFloats(1536.0f+128.0f, 16.0f));
	stars.push_back(TwoFloats(1536.0f+192.0f, 320.0f));
	stars.push_back(TwoFloats(1536.0f+256.0f, 128.0f));
	stars.push_back(TwoFloats(1536.0f+160.0f, 256.0f));

	//y = 314.0f;
	y = (float)getDrawingAreaSize().y-406.0f;
	for(i=0;i<NumLayers;++i)
	{
		waves.push_back(shared_ptr<Wave>(new Wave(y, ((i%2) > 0))));
		layers[i].addEntity(dynamic_pointer_cast<LayerEntity>(waves.back()));

		//y += ((float)getDrawingAreaSize().y-314.0f)/(float)NumLayers;
		y += 406.0f/(float)NumLayers;
	}
}

//------------------------------------------------------------------------------
TitleScreen::~TitleScreen()
{

}

//------------------------------------------------------------------------------
void TitleScreen::update()
{
	unsigned int i;

	for(i=0;i<waves.size();++i)
		waves[i]->update();
}

//------------------------------------------------------------------------------
void TitleScreen::draw(DrawerPtr& d, float timestepInterp)
{
	int i;
	TwoFloats tempPos;
	const TwoFloats centre(d->getDrawingAreaSize() * 0.5f);
	float playerPos = 0.0f;

	if(playerPos < centre.x)
		backgroundOffset = 0.0f;
	else
		backgroundOffset = (playerPos - centre.x)/8.0f;

	//Fill background colour.
	d->fillRect(0.0f, d->getDrawingAreaSize(), ThreeFloats(0.0f));

	//Draw stars.
	for(i=0;i<stars.size();i+=3)
	{
		tempPos = stars[i];
		tempPos.x -= backgroundOffset*0.5f;
		if(tempPos.x < d->getDrawingAreaSize().x)
			d->drawImage(L"Star1", tempPos);
	}
	for(i=1;i<stars.size();i+=3)
	{
		tempPos = stars[i];
		tempPos.x -= backgroundOffset*0.5f;
		if(tempPos.x < d->getDrawingAreaSize().x)
			d->drawImage(L"Star2", tempPos);
	}
	for(i=2;i<stars.size();i+=3)
	{
		tempPos = stars[i];
		tempPos.x -= backgroundOffset*0.5f;
		if(tempPos.x < d->getDrawingAreaSize().x)
			d->drawImage(L"Star3", tempPos);
	}

	//Draw moon.
	tempPos = moonPos;
	tempPos.x -= backgroundOffset*0.5f;
	d->drawImage(L"Moon", tempPos);

	//Draw layers.
	for(i=0;i<NumLayers;++i)
		layers[i].draw(d, backgroundOffset * 8.0f);

	//Draw title text.
	d->drawImage(L"Title",
				 TwoFloats(centre.x-530.0f, 16.0f));

	if(fadeIn > 0.0f)
	{
		d->fillRect(0.0f, d->getDrawingAreaSize(), 0.0f, fakeLog(fadeIn));
		fadeIn -= 0.05f;
	}
}

//------------------------------------------------------------------------------
void TitleScreen::keyDown(const wstring& action,
							const wstring& keyPressed,
							int keyModifier)
{
	if(action == L"Escape")
		quit();
	else if((keyPressed != L"F10") && (keyPressed != L"F9"))
		nextState(L"GamePlayState");
}
