//	Wave.cpp - Class representing a single line of waves.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "Random.h"
#include "Wave.h"

//------------------------------------------------------------------------------
Wave::Wave(float y, bool offset):
yPos(y)
{
	if(offset)
		texOffset = 0.25f;
	else
		texOffset = 0.0f;

	sinIndex = Random::getGlobal().getRandomFloat();
	sinSpeed = 0.002f + (Random::getGlobal().getRandomFloat() * 0.004f);
}

//------------------------------------------------------------------------------
Wave::~Wave()
{

}

//------------------------------------------------------------------------------
void Wave::update()
{
	sinIndex += sinSpeed;
	if(sinIndex > 1.0f)
		sinIndex = 0.0f;
}

//------------------------------------------------------------------------------
void Wave::draw(shared_ptr<Drawer>& d, float xOffset)
{
	TwoFloats tilePos;
	const TwoFloats tileSize(d->getDrawingAreaSize().x/512.0f, 0.99f);
	const TwoFloats tempPos(0.0f, yPos + (sinf(sinIndex * 2.0f * NIALL_PI) * 4.0f));
	const TwoFloats tempSize(d->getDrawingAreaSize().x, 128.0f);

	tilePos.x = texOffset + (xOffset/512.0f);
	tilePos.y = 0.01f;
	d->drawTiledImage(L"Waves",
					  tempPos,
					  tempSize,
					  tilePos,
					  tileSize);
}
