//	Wave.h - Class representing a single line of waves.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef WAVE_H_
#define WAVE_H_

#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Layer.h"

class Drawer;

///	Class representing a single line of waves.
class Wave : public LayerEntity
{
  public:
	///	Constructor.
	Wave(float y, bool offset);
	///	Destructor.
	~Wave();

	///	Updates the wave's motion.
	void update();
	///	Draws the wave.
	void draw(shared_ptr<Drawer>& d, float xOffset);

	///	Returns 0.
	float getPosition() const {return 0.0f;};
	///	Returns false (waves do not collide with anything).
	bool getCollides() const {return false;};
	///	Returns the entity's type name.
	const std::wstring getType() const {return L"Wave";};
  private:
	///	The wave's draw position.
	float yPos;
	///	The wave's texture offset.
	float texOffset;

	///	Used to move the wave up and down.
	float sinIndex;
	///	Used to move the wave up and down.
	float sinSpeed;
};

#endif
