//	WhirlingAnimals.cpp - One of the laudanum effects.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "WhirlingAnimals.h"
#include "drawing/Drawer.h"
#include "MiscHelper.h"
#include "Random.h"

//------------------------------------------------------------------------------
WhirlingAnimals::WhirlingAnimals()
{
	int i;
	std::wstring images[] = {L"AnimalBeavuck",
							 L"AnimalElemu",
							 L"AnimalGirager",
							 L"AnimalLioningo",
							 L"AnimalSlithersheep",
							 L"AnimalWheelybox"};

	for(i=0;i<NumAnimals;++i)
	{
		animals[i].image = images[Random::getGlobal().getRandomInt(6)];
		animals[i].radius = fakeLog(Random::getGlobal().getRandomFloat()) * 1280.0f;
		animals[i].index = Random::getGlobal().getRandomFloat();
		animals[i].speed = 0.001f + (Random::getGlobal().getRandomFloat() * 0.002f);
		if(Random::getGlobal().getRandomFloat() > 0.5f)
			animals[i].speed *= -1.0f;
	}
}

//------------------------------------------------------------------------------
WhirlingAnimals::~WhirlingAnimals()
{

}

//------------------------------------------------------------------------------
void WhirlingAnimals::draw(shared_ptr<Drawer>& d)
{
	int i;
	float tempAngle;
	TwoFloats tempPos;
	TwoFloats pivotPos;
	const TwoFloats centre(d->getDrawingAreaSize() * 0.5f);

	for(i=0;i<NumAnimals;++i)
	{
		pivotPos = d->getInternalImageData(animals[i].image)->size * 0.5f;

		tempPos = centre;
		tempPos -= pivotPos;
		tempAngle = animals[i].index * 2.0f * NIALL_PI;
		tempPos.x += sinf(tempAngle) * animals[i].radius;
		tempPos.y += cosf(tempAngle) * animals[i].radius;

		d->drawRotImage(animals[i].image,
						tempPos,
						tempAngle,
						pivotPos,
						1.0f,
						1.0f,
						0.5f);

		animals[i].index += animals[i].speed;
		if(animals[i].index > 1.0f)
			animals[i].index = 0.0f;
		else if(animals[i].index < 0.0f)
			animals[i].index = 1.0f;
	}
}
